@@ -22,13 +22,16 @@
 #include <QMenu>
 
 #include "ui_qgsstylemanagerdialogbase.h"
-#include "qgshelp.h"
 #include "qgsstylemodel.h"
 #include "qgis_gui.h"
+#include "qgis_sip.h"
+#include "qgssettingstree.h"
 
 class QgsStyle;
 class QgsTemporaryCursorOverride;
 class QgsMessageBar;
+class QgsProjectStyleDatabaseModel;
+class QgsSettingsEntryString;
 
 #ifndef SIP_RUN
 ///@cond PRIVATE
@@ -69,6 +72,16 @@ class GUI_EXPORT QgsStyleManagerDialog : public QDialog, private Ui::QgsStyleMan
     Q_OBJECT
 
   public:
+#ifndef SIP_RUN
+
+    static inline QgsSettingsTreeNode *sTtreeStyleManager = QgsSettingsTree::sTreeApp->createChildNode( QStringLiteral( "style-manager" ) );
+
+    /**
+     * Last used folder for generic style database actions.
+     * \since QGIS 3.26
+     */
+    static const QgsSettingsEntryString *settingLastStyleDatabaseFolder;
+#endif
 
     /**
      * Constructor for QgsStyleManagerDialog, with the specified \a parent widget and window \a flags.
@@ -80,6 +93,15 @@ class GUI_EXPORT QgsStyleManagerDialog : public QDialog, private Ui::QgsStyleMan
     QgsStyleManagerDialog( QgsStyle *style, QWidget *parent SIP_TRANSFERTHIS = nullptr, Qt::WindowFlags flags = Qt::WindowFlags(),
                            bool readOnly = false );
 
+    /**
+     * Constructor for QgsStyleManagerDialog, with the specified \a parent widget and window \a flags.
+     *
+     * All styles linked to the current project will be available.
+     *
+     * \since QGIS 3.26
+     */
+    QgsStyleManagerDialog( QWidget *parent SIP_TRANSFERTHIS = nullptr, Qt::WindowFlags flags = Qt::WindowFlags() );
+
     // TODO QGIS 4.0 -- rename "RampType" to "rampType".
 
     /**
@@ -347,7 +369,15 @@ class GUI_EXPORT QgsStyleManagerDialog : public QDialog, private Ui::QgsStyleMan
 
     void pasteItem();
 
+    void setThumbnailSize( int );
+
+    void currentStyleAboutToBeDestroyed();
+
   private:
+
+    void init();
+
+    void setCurrentStyle( QgsStyle *style );
     int selectedItemType();
 
     /**
@@ -355,6 +385,8 @@ class GUI_EXPORT QgsStyleManagerDialog : public QDialog, private Ui::QgsStyleMan
      */
     bool allTypesSelected() const;
 
+    bool isReadOnly() const;
+
     struct ItemDetails
     {
       QgsStyle::StyleEntity entityType;
@@ -362,6 +394,12 @@ class GUI_EXPORT QgsStyleManagerDialog : public QDialog, private Ui::QgsStyleMan
       QString name;
     };
 
+    enum GroupModelRoles
+    {
+      Name = Qt::UserRole + 1,
+      TagName
+    };
+
     QList< ItemDetails > selectedItems();
 
     /**
@@ -377,6 +415,8 @@ class GUI_EXPORT QgsStyleManagerDialog : public QDialog, private Ui::QgsStyleMan
 
     QgsCheckableStyleModel *mModel = nullptr;
 
+    QgsProjectStyleDatabaseModel *mProjectStyleModel = nullptr;
+
     QString mStyleFilename;
 
     bool mModified = false;
@@ -387,6 +427,8 @@ class GUI_EXPORT QgsStyleManagerDialog : public QDialog, private Ui::QgsStyleMan
     //! space to store symbol tags
     QStringList mTagList;
 
+    QMenu *mShareMenu = nullptr;
+
     //! Context menu for the symbols/colorramps
     QMenu *mGroupMenu = nullptr;
 
@@ -415,18 +457,23 @@ class GUI_EXPORT QgsStyleManagerDialog : public QDialog, private Ui::QgsStyleMan
 
     QAction *mActionCopyItem = nullptr;
     QAction *mActionPasteItem = nullptr;
+    QAction *mExportAction = nullptr;
+    QAction *mImportAction = nullptr;
 
     int mBlockGroupUpdates = 0;
+    int mBlockStyleDatabaseChanges = 0;
 
     bool mReadOnly = false;
     bool mFavoritesGroupVisible = true;
     bool mSmartGroupVisible = true;
     QString mBaseName;
 
+    static QString sPreviousTag;
+
     bool addTextFormat();
     bool editTextFormat();
 
-    bool addLabelSettings( QgsWkbTypes::GeometryType type );
+    bool addLabelSettings( Qgis::GeometryType type );
     bool editLabelSettings();
 
     bool addLegendPatchShape( Qgis::SymbolType type );
@@ -435,6 +482,8 @@ class GUI_EXPORT QgsStyleManagerDialog : public QDialog, private Ui::QgsStyleMan
     bool addSymbol3D( const QString &type );
     bool editSymbol3D();
 
+    void addStyleDatabase( bool createNew );
+
     friend class QgsStyleExportImportDialog;
 };
 
