@@ -21,6 +21,7 @@
 
 #include "qgis_core.h"
 #include "qgis_sip.h"
+#include "qgsabstractdatabaseproviderconnection.h"
 #include "qgsfields.h"
 #include "qgsfeedback.h"
 #include "qgsogrutils.h"
@@ -193,9 +194,8 @@ class CORE_EXPORT QgsVectorFileWriter : public QgsFeatureSink
 
     /**
      * Options for sorting and filtering vector formats.
-     * \since QGIS 3.0
      */
-    enum VectorFormatOption
+    enum VectorFormatOption SIP_ENUM_BASETYPE( IntFlag )
     {
       SortRecommended = 1 << 1, //!< Use recommended sort order, with extremely commonly used formats listed first
       SkipNonSpatialFormats = 1 << 2, //!< Filter out any formats which do not have spatial support (e.g. those which cannot save geometries)
@@ -206,7 +206,6 @@ class CORE_EXPORT QgsVectorFileWriter : public QgsFeatureSink
     /**
      * \ingroup core
      * \brief Interface to convert raw field values to their user-friendly value.
-     * \since QGIS 2.16
      */
     class CORE_EXPORT FieldValueConverter
     {
@@ -239,9 +238,8 @@ class CORE_EXPORT QgsVectorFileWriter : public QgsFeatureSink
 
     /**
      * Edition capability flags
-     * \since QGIS 3.0
     */
-    enum EditionCapability
+    enum EditionCapability SIP_ENUM_BASETYPE( IntFlag )
     {
       //! Flag to indicate that a new layer can be added to the dataset
       CanAddNewLayer                 = 1 << 0,
@@ -258,13 +256,11 @@ class CORE_EXPORT QgsVectorFileWriter : public QgsFeatureSink
 
     /**
      * Combination of CanAddNewLayer, CanAppendToExistingLayer, CanAddNewFieldsToExistingLayer or CanDeleteLayer
-     * \since QGIS 3.0.
     */
     Q_DECLARE_FLAGS( EditionCapabilities, EditionCapability )
 
     /**
      * Enumeration to describe how to handle existing files
-     * \since QGIS 3.0
      */
     enum ActionOnExistingFile
     {
@@ -386,7 +382,6 @@ class CORE_EXPORT QgsVectorFileWriter : public QgsFeatureSink
      * \param attributes attributes to export (empty means all unless skipAttributeCreation is set)
      * \param fieldValueConverter field value converter (added in QGIS 2.16)
      * \param newLayer QString pointer which will contain the new layer name created (in case it is different to the provided layer name) (added in QGIS 3.4, not available in python)
-     * \since QGIS 2.2
      * \deprecated Use writeAsVectorFormatV2() instead.
      */
 #else
@@ -414,7 +409,6 @@ class CORE_EXPORT QgsVectorFileWriter : public QgsFeatureSink
      * \param includeZ set to TRUE to include z dimension in output. This option is only valid if overrideGeometryType is set. (added in QGIS 2.14)
      * \param attributes attributes to export (empty means all unless skipAttributeCreation is set)
      * \param fieldValueConverter field value converter (added in QGIS 2.16)
-     * \since QGIS 2.2
      * \deprecated Use writeAsVectorFormatV2() instead.
      */
 #endif
@@ -446,7 +440,6 @@ class CORE_EXPORT QgsVectorFileWriter : public QgsFeatureSink
     /**
      * \ingroup core
      * \brief Options to pass to writeAsVectorFormat()
-     * \since QGIS 3.0
      */
     class CORE_EXPORT SaveVectorOptions
     {
@@ -555,6 +548,26 @@ class CORE_EXPORT QgsVectorFileWriter : public QgsFeatureSink
          * \since QGIS 3.34
          */
         bool includeConstraints = false;
+
+        /**
+         * Set to TRUE to transfer field domains to the exported vector file.
+         *
+         * Support for field domains depends on the output file format.
+         *
+         * \note Only available in builds based on GDAL 3.5 or later
+         * \since QGIS 3.36
+         */
+        bool setFieldDomains = true;
+
+        /**
+         * Source database provider connection, for field domains.
+         *
+         * Ownership is not transferred and callers must ensure that the lifetime of sourceDatabaseProviderConnection
+         * exceeds the lifetime of the QgsVectorFileWriter object.
+         *
+         * \since QGIS 3.36
+         */
+        const QgsAbstractDatabaseProviderConnection *sourceDatabaseProviderConnection = nullptr;
     };
 
 #ifndef SIP_RUN
@@ -567,7 +580,6 @@ class CORE_EXPORT QgsVectorFileWriter : public QgsFeatureSink
      * \param newFilename QString pointer which will contain the new file name created (in case it is different to fileName).
      * \param errorMessage will be set to the error message text, if an error occurs while writing the layer
      * \param newLayer QString pointer which will contain the new layer name created (in case it is different to the provided layer name) (added in QGIS 3.4, not available in python)
-     * \since QGIS 3.0
      * \deprecated Use writeAsVectorFormatV2() instead.
      */
 #else
@@ -579,7 +591,6 @@ class CORE_EXPORT QgsVectorFileWriter : public QgsFeatureSink
      * \param options options.
      * \param newFilename QString pointer which will contain the new file name created (in case it is different to fileName).
      * \param errorMessage will be set to the error message text, if an error occurs while writing the layer
-     * \since QGIS 3.0
      * \deprecated Use writeAsVectorFormatV2() instead.
      */
 #endif
@@ -636,6 +647,8 @@ class CORE_EXPORT QgsVectorFileWriter : public QgsFeatureSink
      * \param sinkFlags feature sink flags (added in QGIS 3.10.3)
      * \param fieldNameSource source for field names (since QGIS 3.18)
      * \param includeConstraints set to TRUE to copy field constraints to the destination layer (since QGIS 3.34)
+     * \param setFieldDomains set to TRUE to copy field domains (since QGIS 3.36)
+     * \param sourceDatabaseProviderConnection source database provider connection, for field domains (since QGIS 3.36)
      * \note not available in Python bindings
      * \deprecated Use create() instead.
      */
@@ -656,7 +669,9 @@ class CORE_EXPORT QgsVectorFileWriter : public QgsFeatureSink
                                            const QgsCoordinateTransformContext &transformContext = QgsCoordinateTransformContext(),
                                            QgsFeatureSink::SinkFlags sinkFlags = QgsFeatureSink::SinkFlags(),
                                            FieldNameSource fieldNameSource = Original,
-                                           bool includeConstraints = false
+                                           bool includeConstraints = false,
+                                           bool setFieldDomains = true,
+                                           const QgsAbstractDatabaseProviderConnection *sourceDatabaseProviderConnection = nullptr
                                          ) SIP_SKIP;
 
     //! QgsVectorFileWriter cannot be copied.
@@ -729,7 +744,6 @@ class CORE_EXPORT QgsVectorFileWriter : public QgsFeatureSink
 
     /**
      * Details of available filters and formats.
-     * \since QGIS 3.0
      */
     struct FilterFormatDetails
     {
@@ -763,7 +777,6 @@ class CORE_EXPORT QgsVectorFileWriter : public QgsFeatureSink
      * returned formats.
      *
      * \see supportedFiltersAndFormats()
-     * \since QGIS 3.0
      */
     static QStringList supportedFormatExtensions( VectorFormatOptions options = SortRecommended );
 
@@ -772,13 +785,11 @@ class CORE_EXPORT QgsVectorFileWriter : public QgsFeatureSink
      *
      * The \a driverName argument must be a valid GDAL driver name.
      *
-     * \since QGIS 3.0
      */
     static bool supportsFeatureStyles( const QString &driverName );
 
     /**
      * Details of available driver formats.
-     * \since QGIS 3.0
      */
     struct DriverDetails
     {
@@ -806,7 +817,6 @@ class CORE_EXPORT QgsVectorFileWriter : public QgsFeatureSink
      * Returns the OGR driver name for a specified file \a extension. E.g. the
      * driver name for the ".shp" extension is "ESRI Shapefile".
      * If no suitable drivers are found then an empty string is returned.
-     * \since QGIS 3.0
      */
     static QString driverForExtension( const QString &extension );
 
@@ -859,7 +869,6 @@ class CORE_EXPORT QgsVectorFileWriter : public QgsFeatureSink
 
     /**
      * Adds a \a feature to the currently opened data source, using the style from a specified \a renderer.
-     * \since QGIS 3.0
      */
     bool addFeatureWithStyle( QgsFeature &feature, QgsFeatureRenderer *renderer, Qgis::DistanceUnit outputUnit = Qgis::DistanceUnit::Meters );
 
@@ -894,7 +903,6 @@ class CORE_EXPORT QgsVectorFileWriter : public QgsFeatureSink
      * Returns the reference scale for output.
      * The  scale value indicates the scale denominator, e.g. 1000.0 for a 1:1000 map.
      * \see setSymbologyScale()
-     * \since QGIS 3.0
      */
     double symbologyScale() const { return mSymbologyScale; }
 
@@ -902,7 +910,6 @@ class CORE_EXPORT QgsVectorFileWriter : public QgsFeatureSink
      * Set reference \a scale for output.
      * The \a scale value indicates the scale denominator, e.g. 1000.0 for a 1:1000 map.
      * \see symbologyScale()
-     * \since QGIS 3.0
      */
     void setSymbologyScale( double scale );
 
@@ -912,7 +919,6 @@ class CORE_EXPORT QgsVectorFileWriter : public QgsFeatureSink
      * Returns a list of the default dataset options for a specified driver.
      * \param driverName name of OGR driver
      * \see defaultLayerOptions()
-     * \since QGIS 3.0
      */
     static QStringList defaultDatasetOptions( const QString &driverName );
 
@@ -920,7 +926,6 @@ class CORE_EXPORT QgsVectorFileWriter : public QgsFeatureSink
      * Returns a list of the default layer options for a specified driver.
      * \param driverName name of OGR driver
      * \see defaultDatasetOptions()
-     * \since QGIS 3.0
      */
     static QStringList defaultLayerOptions( const QString &driverName );
 
@@ -934,20 +939,17 @@ class CORE_EXPORT QgsVectorFileWriter : public QgsFeatureSink
 
     /**
      * Returns edition capabilities for an existing dataset name.
-     * \since QGIS 3.0
      */
     static QgsVectorFileWriter::EditionCapabilities editionCapabilities( const QString &datasetName );
 
     /**
      * Returns whether the target layer already exists.
-     * \since QGIS 3.0
      */
     static bool targetLayerExists( const QString &datasetName,
                                    const QString &layerName );
 
     /**
      * Returns whether there are among the attributes specified some that do not exist yet in the layer
-     * \since QGIS 3.0
      */
     static bool areThereNewFieldsToCreate( const QString &datasetName,
                                            const QString &layerName,
@@ -992,6 +994,9 @@ class CORE_EXPORT QgsVectorFileWriter : public QgsFeatureSink
     //! Whether to transfer field constraints to output
     bool mIncludeConstraints = false;
 
+    //! Whether to set field domains to output
+    bool mSetFieldDomains = true;
+
   private:
 #ifdef SIP_RUN
     QgsVectorFileWriter( const QgsVectorFileWriter &rh );
@@ -1021,6 +1026,7 @@ class CORE_EXPORT QgsVectorFileWriter : public QgsFeatureSink
       QgsGeometry filterRectGeometry;
       std::unique_ptr< QgsGeometryEngine  > filterRectEngine;
       QVariantMap providerUriParams;
+      std::unique_ptr< QgsAbstractDatabaseProviderConnection > sourceDatabaseProviderConnection;
     };
 
     /**
@@ -1072,7 +1078,8 @@ class CORE_EXPORT QgsVectorFileWriter : public QgsFeatureSink
                const QString &layerName,
                QgsVectorFileWriter::ActionOnExistingFile action, QString *newLayer, QgsFeatureSink::SinkFlags sinkFlags,
                const QgsCoordinateTransformContext &transformContext,
-               FieldNameSource fieldNameSource );
+               FieldNameSource fieldNameSource,
+               const QgsAbstractDatabaseProviderConnection *sourceDatabaseProviderConnection );
     void resetMap( const QgsAttributeList &attributes );
 
     std::unique_ptr< QgsFeatureRenderer > mRenderer;
